@@ -1,5 +1,6 @@
 import argparse
 import dataclasses
+import typing
 
 
 @dataclasses.dataclass(frozen=True)
@@ -17,7 +18,7 @@ class ExecutionResult:
     #: Exit identifier specifying how the command was resolved.
     code: str
     #: Message for the associated result.
-    message: str = None
+    message: typing.Optional[str] = None
 
     def echo(self) -> "ExecutionResult":
         """Echoes the result if set for display to the console."""
